Error types of someip_parse.
Structs
- LenError
- Error when different lengths are conflicting with each other (e.g. not enough data in a slice to decode a header).
- Slice
Write Space Error - Error when not enough space is available in a slice to write a packet or header to it.
- TpOffset
NotMultiple Of16 Error - Error if the offset of the tp header is not a multiple of 16.
Enums
- Layer
- Layers on which an error can occur.
- LenSource
- Sources of length values that limit lower layers.
- SdRead
Error - Errors that can occur when reading someip headers.
- SdValue
Error - Range errors in fields of the someip & tp header struct. These can occur when serializing or modifying an error.
- SdWrite
Error - Errors that can occur when serializing a someip & tp header.
- Someip
Header Error - Errors that can occur when reading someip headers.
- Someip
Header Read Error - Error when decoding an SOMEIP header via a
std::io::Readsource. - Someip
Slice Error - Error when decoding an SOMEIP header & payload from a slice.
- TpBuf
Config Error - TpReassemble
Error