pub enum SdWriteError {
IoError(Error),
UnexpectedEndOfSlice(usize),
ValueError(SdValueError),
}Expand description
Errors that can occur when serializing a someip & tp header.
Variants
IoError(Error)
UnexpectedEndOfSlice(usize)
The slice length was not large enough to write the header.
ValueError(SdValueError)
Error in the data that was attempted to be written