pub struct UnknownDiscardableOption {
pub length: u16,
pub option_type: u8,
}Expand description
An unknown option that is flagged as “discardable” and should be ignored by the receiver if not supported.
This option is only intended to be used for reading, to ensure the option indices are still matching. In case this option is passed to a write function an error will be triggered.
Fields
length: u16option_type: u8Trait Implementations
Sourceimpl Clone for UnknownDiscardableOption
impl Clone for UnknownDiscardableOption
Sourcefn clone(&self) -> UnknownDiscardableOption
fn clone(&self) -> UnknownDiscardableOption
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnknownDiscardableOption
impl Debug for UnknownDiscardableOption
Sourceimpl From<UnknownDiscardableOption> for SdOption
impl From<UnknownDiscardableOption> for SdOption
Sourcefn from(o: UnknownDiscardableOption) -> Self
fn from(o: UnknownDiscardableOption) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for UnknownDiscardableOption
impl PartialEq for UnknownDiscardableOption
impl Eq for UnknownDiscardableOption
impl StructuralPartialEq for UnknownDiscardableOption