SomeipHeader

Struct SomeipHeader 

pub struct SomeipHeader {
    pub message_id: u32,
    pub length: u32,
    pub request_id: u32,
    pub interface_version: u8,
    pub message_type: MessageType,
    pub return_code: u8,
    pub tp_header: Option<TpHeader>,
}
SOMEIP header (including tp header if present).

Fields

message_id: u32length: u32request_id: u32interface_version: u8message_type: MessageType

Message type (does not contain the tp flag, this is determined if something is present in the tp_header field).

return_code: u8tp_header: Option<TpHeader>

Contains a tp header (Transporting large SOME/IP messages of UDP [SOME/IP-TP]).

If there is a tp header a someip payload is split over multiple messages and the tp header contains the start offset of the payload of this message relative to the completly assembled payload.

Implementations

Source

impl SomeipHeader

pub fn new_sd_header( length: u32, session_id: u16, tp_header: Option<TpHeader>, ) -> Self

Create a service discovery message header.

pub fn service_id(&self) -> u16

Returns the service id (first 16 bits of the message id)

pub fn set_service_id(&mut self, service_id: u16)

Set the servide id (first 16 bits of the message id)

pub fn set_event_id(&mut self, event_id: u16)

Set the event id + the event bit.

pub fn set_method_id(&mut self, method_id: u16)

Set the event id + the event bit to 0. Asserting method_id <= 0x7FFF (otherwise the )

pub fn set_method_or_event_id(&mut self, method_id: u16)

Sets the event id or method id. This number mjust include the “event bit”.

pub fn is_someip_sd(&self) -> bool

Returns true if the message has the message id of a some ip service discovery message.

pub fn is_event(&self) -> bool

Returns true if the event or notification bit in the message id is set

pub fn event_or_method_id(&self) -> u16

Return the event id or method id. This number includes the “event bit”.

pub fn event_id(&self) -> Option<u16>

Return the event id. None if event bit is not set.

pub fn method_id(&self) -> Option<u16>

Return the method id. None if event bit is set.

pub fn write_raw<T: Write>(&self, writer: &mut T) -> Result<(), Error>

Serialize the header.

pub fn base_to_bytes(&self) -> [u8; 16]

Returns the encoded SOMEIP header (without the TP header).

pub fn read<T: Read>( reader: &mut T, ) -> Result<SomeipHeader, SomeipHeaderReadError>

Read a header from a byte stream.